@@ -1,8 +1,8 @@
 #' Collinearity Diagnostics
 #'
-#' This function computes tolerance, standard error inflation factor, variance inflation
-#' factor, eigenvalues, condition index, and variance proportions for linear, generalized
-#' linear, and mixed-effects models.
+#' This function computes tolerance, standard error inflation factor, variance
+#' inflation factor, eigenvalues, condition index, and variance proportions for
+#' linear, generalized linear, and mixed-effects models.
 #'
 #' Collinearity diagnostics can be conducted for objects returned from the \code{lm()}
 #' and \code{glm()} function, but also from objects returned from the \code{lmer()}
@@ -10,27 +10,29 @@
 #' from the \pkg{nlme} package, and the \code{glmmTMB()} function from the \pkg{glmmTMB}
 #' package.
 #'
-#' The generalized variance inflation factor (Fox & Monette, 1992) is computed for
-#' terms with more than 1 df resulting from factors with more than two levels. The
-#' generalized VIF (GVIF) is interpretable as the inflation in size of the confidence
-#' ellipse or ellipsoid for the coefficients of the term in comparison with what would
-#' be obtained for orthogonal data. GVIF is invariant to the coding of the terms in
-#' the model. In order to adjust for the dimension of the confidence ellipsoid,
-#' GVIF\eqn{^\frac{1}{2df}} is computed. Note that the adjusted GVIF (aGVIF) is
-#' actually a generalized standard error inflation factor (GSIF). Thus, the aGIF
-#' needs to be squared before applying a common cutoff threshold for the VIF (e.g.,
-#' VIF > 10). Note that the output of \code{check.collin()} function reports either
-#' the variance inflation factor or the squared generalized variance inflation factor
-#' in the column \code{VIF}, while the standard error inflation factor or the adjusted
-#' generalized variance inflation factor is reported in the column \code{SIF}.
+#' The generalized variance inflation factor (Fox & Monette, 1992) is computed
+#' for terms with more than 1 df resulting from factors with more than two levels.
+#' The generalized VIF (GVIF) is interpretable as the inflation in size of the
+#' confidence ellipse or ellipsoid for the coefficients of the term in comparison
+#' with what would be obtained for orthogonal data. GVIF is invariant to the
+#' coding of the terms in the model. In order to adjust for the dimension of the
+#' confidence ellipsoid, GVIF\eqn{^\frac{1}{2df}} is computed. Note that the
+#' adjusted GVIF (aGVIF) is actually a generalized standard error inflation factor
+#' (GSIF). Thus, the aGIF needs to be squared before applying a common cutoff
+#' threshold for the VIF (e.g., VIF > 10). Note that the output of \code{check.collin()}
+#' function reports either the variance inflation factor or the squared generalized
+#' variance inflation factor in the column \code{VIF}, while the standard error
+#' inflation factor or the adjusted generalized variance inflation factor is
+#' reported in the column \code{SIF}.
 #'
-#' @param model    a fitted model of class \code{"lm"}, \code{"glm"}, \code{"lmerMod"},
-#'                 \code{"lmerModLmerTest"}, \code{"glmerMod"}, \code{"lme"}, or
-#'                 \code{"glmmTMB"}.
-#' @param print    a character vector indicating which results to show, i.e. \code{"all"},
-#'                 for all results, \code{"vif"} for tolerance, std. error inflation
-#'                 factor, and variance inflation factor, or \code{eigen} for eigenvalue,
-#'                 condition index, and variance proportions.
+#' @param model    a fitted model of class \code{"lm"}, \code{"glm"},
+#'                 \code{"lmerMod"}, \code{"lmerModLmerTest"}, \code{"glmerMod"},
+#'                 \code{"lme"}, or \code{"glmmTMB"}.
+#' @param print    a character vector indicating which results to show, i.e.
+#'                 \code{"all"}, for all results, \code{"vif"} for tolerance,
+#'                 std. error inflation factor, and variance inflation factor,
+#'                 or \code{eigen} for eigenvalue, condition index, and variance
+#'                 proportions.
 #' @param digits   an integer value indicating the number of decimal places to be
 #'                 used for displaying results.
 #' @param p.digits an integer value indicating the number of decimal places to be
@@ -42,8 +44,10 @@
 #'                 to an existing text file with extension \code{.txt} specified
 #'                 in \code{write}, if \code{FALSE} existing text file will be
 #'                 overwritten.
-#' @param check    logical: if \code{TRUE} (default), argument specification is checked.
-#' @param output   logical: if \code{TRUE} (default), output is shown on the console.
+#' @param check    logical: if \code{TRUE} (default), argument specification is
+#'                 checked.
+#' @param output   logical: if \code{TRUE} (default), output is shown on the
+#'                 console.
 #'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
@@ -64,13 +68,17 @@
 #' @return
 #' Returns an object of class \code{misty.object}, which is a list with following
 #' entries:
-#' \tabular{ll}{
-#' \code{call} \tab function call \cr
-#' \code{type} \tab type of analysis \cr
-#' \code{model} \tab model specified in the \code{model} argument \cr
-#' \code{args} \tab specification of function arguments \cr
-#' \code{result} \tab list with result tables \cr
-#' }
+#'
+#' \item{\code{call}}{function call}
+#' \item{\code{type}}{type of analysis}
+#' \item{\code{model}}{model specified in the \code{model} argument}
+#' \item{\code{args}}{specification of function arguments}
+#' \item{\code{result}}{list with result tables, i.e., \code{coef} for the regression
+#'                      table including tolerance, std. error inflation factor and
+#'                      variance inflation factors, \code{vif} for the tolerance,
+#'                      std. error inflation factor, and variance inflation factor,
+#'                      and \code{eigen} for eigenvalue condition index, and variance
+#'                      proportion}
 #'
 #' @note
 #' The computation of the VIF and the GVIF is based on the \code{vif()} function
@@ -88,8 +96,7 @@
 #'                   x3 = c(7, 3, 4, 2, 5, 6, 4, 2, 3, 5, 2, 8),
 #'                   x4 = c("a", "b", "a", "c", "c", "c", "a", "b", "b", "c", "a", "c"),
 #'                   y1 = c(2, 7, 4, 4, 7, 8, 4, 2, 5, 1, 3, 8),
-#'                   y2 = c(0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1),
-#'                   stringsAsFactors = TRUE)
+#'                   y2 = c(0, 1, 0, 1, 1, 1, 0, 0, 0, 1, 0, 1), stringsAsFactors = TRUE)
 #'
 #' #----------------------------------------------------------------------------
 #' # Linear model
@@ -120,23 +127,26 @@
 #' check.collin(mod.glm)
 #'
 #' \dontrun{
+#' # Load lme4, nlme, and glmmTMB package
+#' libraries(lme4, nlme, glmmTMB)
+#'
 #' #----------------------------------------------------------------------------
 #' # Linear mixed-effects model
 #'
-#' # Estimate linear mixed-effects model with continuous predictors using lme4 package
-#' mod.lmer <- lme4::lmer(y1 ~ x1 + x2 + x3 + (1|group), data = dat)
+#' # Estimate linear mixed-effects model using lme4 package
+#' mod.lmer <- lmer(y1 ~ x1 + x2 + x3 + (1|group), data = dat)
 #'
 #' # Example 5: Tolerance, std. error, and variance inflation factor
 #' check.collin(mod.lmer)
 #'
-#' # Estimate linear mixed-effects model with continuous predictors using nlme package
-#' mod.lme <- nlme::lme(y1 ~ x1 + x2 + x3, random = ~ 1 | group, data = dat)
+#' # Estimate linear mixed-effects model using nlme package
+#' mod.lme <- lme(y1 ~ x1 + x2 + x3, random = ~ 1 | group, data = dat)
 #'
 #' # Example 6: Tolerance, std. error, and variance inflation factor
 #' check.collin(mod.lme)
 #'
-#' # Estimate linear mixed-effects model with continuous predictors using glmmTMB package
-#' mod.glmmTMB1 <- glmmTMB::glmmTMB(y1 ~ x1 + x2 + x3 + (1|group), data = dat)
+#' # Estimate linear mixed-effects model using glmmTMB package
+#' mod.glmmTMB1 <- glmmTMB(y1 ~ x1 + x2 + x3 + (1|group), data = dat)
 #'
 #' # Example 7: Tolerance, std. error, and variance inflation factor
 #' check.collin(mod.glmmTMB1)
@@ -144,14 +154,14 @@
 #' #----------------------------------------------------------------------------
 #' # Generalized linear mixed-effects model
 #'
-#' # Estimate mixed-effects logistic regression model with continuous predictors using lme4 package
-#' mod.glmer <- lme4::glmer(y2 ~ x1 + x2 + x3 + (1|group), data = dat, family = "binomial")
+#' # Estimate mixed-effects logistic regression model using lme4 package
+#' mod.glmer <- glmer(y2 ~ x1 + x2 + x3 + (1|group), data = dat, family = "binomial")
 #'
 #' # Example 8: Tolerance, std. error, and variance inflation factor
 #' check.collin(mod.glmer)
 #'
-#' # Estimate mixed-effects logistic regression model with continuous predictors using glmmTMB package
-#' mod.glmmTMB2 <- glmmTMB::glmmTMB(y2 ~ x1 + x2 + x3 + (1|group), data = dat, family = "binomial")
+#' # Estimate mixed-effects logistic regression model using glmmTMB package
+#' mod.glmmTMB2 <- glmmTMB(y2 ~ x1 + x2 + x3 + (1|group), data = dat, family = "binomial")
 #'
 #' # Example 9: Tolerance, std. error, and variance inflation factor
 #' check.collin(mod.glmmTMB2)
@@ -177,43 +187,17 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
   if (isTRUE(is.null(model))) { stop("Input specified for the argument 'model' is NULL.", call. = FALSE) }
 
   # Check if input 'model' is "lm", "glm", "lmerMod", "lmerModLmerTest", "glmerMod", "lme", or "glmmTMB"
-  if (isTRUE(!all(class(model) %in% c("lm", "glm", "lmerMod", "lmerModLmerTest", "glmerMod", "lme", "glmmTMB")))) {
-
-    stop("Please specify an \"lm\", \"glm\", \"lmerMod\", \"lmerModLmerTest\", \"glmerMod\", \"lme\", or \"glmmTMB\" object for the argument 'model'.", call. = FALSE)
-
-  }
+  if (isTRUE(!all(class(model) %in% c("lm", "glm", "lmerMod", "lmerModLmerTest", "glmerMod", "lme", "glmmTMB")))) { stop("Please specify an \"lm\", \"glm\", \"lmerMod\", \"lmerModLmerTest\", \"glmerMod\", \"lme\", or \"glmmTMB\" object for the argument 'model'.", call. = FALSE) }
 
   # Check if model has more than one predictor variable
   if (isTRUE(length(labels(terms(model))) < 2L)) { stop("Please specify a model with more than one predictor variable.", call. = FALSE) }
 
-  # Check input 'check'
-  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
-
   #_____________________________________________________________________________
   #
   # Input Check ----------------------------------------------------------------
 
-  if (isTRUE(check)) {
-
-    # Check input 'print'
-    if (isTRUE(!all(print %in% c("all", "vif", "eigen")))) { stop("Character strings in the argument 'print' do not all match with \"all\", \"vif\", or \"eigen\".", call. = FALSE) }
-
-    # Check input 'digits'
-    if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE) }
-
-    # Check input 'p.digits'
-    if (isTRUE(p.digits %% 1L != 0L || p.digits < 0L)) { stop("Specify a positive integer number for the argument 'p.digits'.", call. = FALSE) }
-
-    # Check input 'write'
-    if (isTRUE(!is.null(write) && substr(write, nchar(write) - 3L, nchar(write)) != ".txt")) { stop("Please specify a character string with file extenstion '.txt' for the argument 'write'.") }
-
-    # Check input 'append'
-    if (isTRUE(!is.logical(append))) { stop("Please specify TRUE or FALSE for the argument 'append'.", call. = FALSE) }
-
-    # Check input 'output'
-    if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
-
-  }
+  # Check inputs
+  .check.input(logical = c("append", "output"), m.character = list(print = c("all", "vif", "eigen")), args = c("digits", "p.digits", "write1"), envir = environment(), input.check = check)
 
   #_____________________________________________________________________________
   #
@@ -235,6 +219,7 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
 
   #...................
   ### Class: lm or glm ####
+
   if (isTRUE(all(class(model) %in% c("lm", "glm")))) {
 
     # Regression model with intercept
@@ -257,6 +242,7 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
 
   #...................
   ### Class: lmerMod, lmerModLmerTest or glmerMod ####
+
   } else if (isTRUE(all(class(model) %in% c("lmerMod", "lmerModLmerTest", "glmerMod", "lme")))) {
 
     # Regression model with intercept
@@ -302,12 +288,9 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
   }
 
   #...................
-  ### Warning message: Model without interceptB ####
-  if (isTRUE(isFALSE(intercept) && "vif" %in% print)) {
+  ### Warning message: Model without intercept ####
 
-    warning("Variance inflation factor might not be sensible in models without an intercept.", call. = FALSE)
-
-  }
+  if (isTRUE(isFALSE(intercept) && "vif" %in% print)) { warning("Variance inflation factor might not be sensible in models without an intercept.", call. = FALSE) }
 
   terms <- labels(terms(model))
 
@@ -315,9 +298,7 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
   det.R <- det(R)
 
   # Result object
-  vif <- data.frame(matrix(0, nrow = length(terms), ncol = 5L,
-                           dimnames = list(terms,  c("Tol", "df", "GVIF", "aGSIF", "aGVIF"))),
-                    stringsAsFactors = FALSE)
+  vif <- data.frame(matrix(0, nrow = length(terms), ncol = 5L, dimnames = list(terms,  c("Tol", "df", "GVIF", "aGSIF", "aGVIF"))))
 
   for (i in seq_along(terms)) {
 
@@ -345,13 +326,11 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
 
   if (isTRUE(all(class(model) %in% c("lmerMod", "lmerModLmerTest", "glmerMod", "lme", "glmmTMB")))) {
 
-    z <- scale(as.data.frame(model.matrix(model, data = model$data), stringsAsFactors = FALSE),
-               center = FALSE, scale = TRUE)
+    z <- scale(as.data.frame(model.matrix(model, data = model$data), stringsAsFactors = FALSE), center = FALSE, scale = TRUE)
 
   } else if (isTRUE(all(class(model) %in% c("lm", "glm")))) {
 
-    z <- scale(as.data.frame(model.matrix(model, data = model$model), stringsAsFactors = FALSE),
-               center = FALSE, scale = TRUE)
+    z <- scale(as.data.frame(model.matrix(model, data = model$model), stringsAsFactors = FALSE), center = FALSE, scale = TRUE)
 
   }
 
@@ -397,8 +376,7 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
   # Match VIF with coefficients
   vif.list <- sapply(row.names(vif), function(y) which(substr(row.names(coeff), 1L, nchar(y)) == y))
 
-  coeff.vif <- matrix(NA, ncol = 5L, nrow = nrow(coeff),
-                      dimnames = list(row.names(coeff), colnames(vif)))
+  coeff.vif <- matrix(NA, ncol = 5L, nrow = nrow(coeff), dimnames = list(row.names(coeff), colnames(vif)))
   for (i in seq_along(vif.list)) {
 
     coeff.vif[vif.list[[i]], ] <- as.matrix(vif[row.names(vif) == names(vif.list)[i], ][rep(1L, times = length(vif.list[[i]])), ])
@@ -411,8 +389,7 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
   object <- list(call = match.call(),
                  type = "check.collin",
                  model = model,
-                 args = list(print = print, digits = digits, p.digits = p.digits,
-                             write = write, append = append, check = check, output = output),
+                 args = list(print = print, digits = digits, p.digits = p.digits, write = write, append = append, check = check, output = output),
                  result = list(coef = coeff, vif = vif, eigen = eigenvalue))
 
   class(object) <- "misty.object"
@@ -448,3 +425,5 @@ check.collin  <- function(model, print = c("all", "vif", "eigen"),
   return(invisible(object))
 
 }
+
+#_______________________________________________________________________________
